searchData={"items":[{"type":"module","title":"ExSnappy","doc":"ExSnappy is a library for taking snapshots of HTML using the Go Snappy service.","ref":"ExSnappy.html"},{"type":"macro","title":"ExSnappy.snap/1","doc":"Takes a snapshot of the given HTML and sends it to the Go Snappy service.\n\nUses the name of the test function as the snapshot name.","ref":"ExSnappy.html#snap/1"},{"type":"macro","title":"ExSnappy.snap/2","doc":"Takes a snapshot of the given HTML with the specified name \n\nUses the name of the test function as the snapshot name plus a suffix. Use if you need to run\nmultiple snapshots in the same test function.","ref":"ExSnappy.html#snap/2"},{"type":"macro","title":"ExSnappy.snap/3","doc":"Takes a snapshot of the given HTML with the specified name and options.\n\nUses the name of the test function as the snapshot name plus a suffix. Use if you need to run\nmultiple snapshots in the same test function.\n\nOptions are passed to the Go Snappy service to control the rendered screenshots.","ref":"ExSnappy.html#snap/3"},{"type":"extras","title":"ExSnappy","doc":"# ExSnappy\n\nGetSnappy is a visual regression testing tool, ExSnappy is used to generate HTML for rendering by GetSnappy.","ref":"readme.html"},{"type":"extras","title":"Installation - ExSnappy","doc":"```elixir\ndef deps do\n  [\n    {:ex_snappy, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - ExSnappy","doc":"There's currently a little bit of ceremony to get the service running, due to a couple of quirks in how testing works for components and LiveView in the testing environment.\n\nWhen a live view is rendered with the `live(...)` function, you get back the full HTML, which includes the necessary ` ` content which loads your CSS.\n\nUnfortunately if you use any of the `render_x(...)` calls, you only get back a subset of the HTML, similarly if you use `render_component` you get the HTML from the individual component, but none of the HTML responsible for loading styles.\n\nCurrently the way to deal with this is to provide `wrapper_fn` function in `test.exs`.  In future we aim to provide a more ergonomic way using your application's templates directly.\n\nThis is essentially the contents of your `root.html.heex`, plus the content of `app.html.heex`.  \n\n**NOTE** Don't add references to load JavaScript.  The reason for this is you don't really want to connect the websocket and have a second page render or deal with things like the 'topbar', which will cause you to have inconsistent images due to timing issues.\n\n```elixir\nconfig :ex_snappy,\n  wrapper_fn: fn inner_content ->\n      \"\"\"\n      <!DOCTYPE html>\n       \n       \n       \n       \n       \n       \n       \n       \n      #{inner_content}\n       \n       \n       \n      \"\"\"\n  end\n```\n\nIf you're running tests locally, you likely don't want to be running the visual regression tests, so we only execute if you explicitly enable things.  Suggested way of dealing with this below\n\n```elixir\nconfig :ex_snappy,\n  enabled: System.get_env(\"EX_SNAPPY_ENABLED\") == \"true\"\n```\n\n# Setup\n\nTo execute the visual regression tests, you'll need to install the binary from https://get-snappy.com/app/downloads \n\nAnd add some configuration data by creating a `.get-snappy.yml` file\n\n```yml\nlocal_dist_dir: \"priv/static\"\nsnappy_workers: 4\ntest_command: \"mix do assets.build, mix test\"\nbrowsers: [\"chrome\"]\n```\n\nYou'll also need to set some environment variables, an example of this is below, but you'd likely get the COMMIT and BRANCH from your CI provider.\n\n```shell\nCOMMIT=$(git rev-parse HEAD)\nBRANCH=$(git rev-parse --abbrev-ref HEAD)\n\nexport GET_SNAPPY_API_KEY=\"your-project-api-ket\"\nexport GET_SNAPPY_COMMIT=$COMMIT\nexport GET_SNAPPY_BRANCH=$BRANCH\n```\n\nFinally, execute the tests you'd run something like this (further information on `EX_SNAPPY_ENABLED` below):\n\n`EX_SNAPPY_ENABLED=true  ./get-snappy snapshot-run`","ref":"readme.html#configuration"},{"type":"extras","title":"Usage - ExSnappy","doc":"The `snap` macro can be used in three forms.  See `ExSnappy` module for further details.\n\nKey steps: \n\n1. `import ExSnappy` to make the `snap` macro available\n\n2. Use the `snap` function to capture screenshots.  **NOTE** Screenshot names are automatically generated based on the name of the `test` function, but if you take multiple screenshots in a single test, you'll need to provide an explicit name to be appended to the test name.\n\n```elixir\ndefmodule MyApp.LiveIndexTest do\n  use MyApp.ConnCase, async: true\n  import Phoenix.LiveViewTest\n\n  import ExSnappy\nend\n```\n\nThen to use in tests, you need send HTML.  This can be achieved by calling `render` only your `live` process, passing the `html` generated from a `live()` call, or the `html` generated from the `render_component` function.","ref":"readme.html#usage"},{"type":"extras","title":"Rendering from `live()` - ExSnappy","doc":"```elixir\ndefmodule MyApp.LiveIndexTest do\n  use MyApp.ConnCase, async: true\n  import Phoenix.LiveViewTest\n\n  import ExSnappy\n  \n  describe \"my tests\" do\n    test \"List projects and project builds\", %{conn: conn, project: project} do\n      # Visit top level builds page\n      {:ok, index_live, html} = live(conn, ~p\"/app/builds\")\n\n      assert html =~ \"Builds\"\n      assert html =~ project.name\n\n      snap(html)\n    end\n  end\nend\n```","ref":"readme.html#rendering-from-live"},{"type":"extras","title":"Using `render()` - ExSnappy","doc":"```elixir\ndefmodule MyApp.LiveIndexTest do\n  use MyApp.ConnCase, async: true\n  import Phoenix.LiveViewTest\n\n  import ExSnappy\n  \n  describe \"my tests\" do\n    test \"List projects and project builds\", %{conn: conn, project: project} do\n      # Visit top level builds page\n      {:ok, index_live, html} = live(conn, ~p\"/app/builds\")\n\n      assert html =~ \"Builds\"\n      assert html =~ project.name\n\n      snap(render(index_live))\n    end\n  end\nend\n```","ref":"readme.html#using-render"},{"type":"extras","title":"Using `render_component()` - ExSnappy","doc":"```elixir\ndefmodule MyApp.PaginationGeneratorTest do\n  use ExUnit.Case, async: true\n  import Phoenix.LiveViewTest\n  import ExSnappy\n\n  test \"Lists elements when no next or previous\" do\n    meta = %Flop.Meta{\n      current_page: 1,\n      total_pages: 10\n    }\n\n    rendered = render_component(&MyApp.Pagination.paginate/1, meta: meta, base_url: \"/hello\")\n\n    snap(rendered)\n\n    assert Floki.find(rendered, \"a\") |> length() == 10\n  end\nend\n```\n\n# Taking multiple screenshots in a single test\n\nSimply provide an explicit name for all but the first call to `snap`.\n\n```elixir\n   test \"multiple screenshots\" do\n      {:ok, index_live, html} = live(conn, ~p\"/app/projects\")\n\n      snap(html)\n\n      assert index_live |> element(\"a\", \"New Project\") |> render_click() =~\n               \"New Project\"\n\n      render_async(index_live)\n\n      snap(\"after patch\", render(index_live))\n\n      assert index_live\n             |> form(\"#project-form\", project: @invalid_attrs)\n             |> render_change() =~ \"can&#39;t be blank\"\n\n      snap(\"With errors\", render(index_live))\n\n      assert index_live\n             |> form(\"#project-form\",\n               project:\n                 @create_attrs\n                 |> Map.put(:repository_full_name, \"some/repo\")\n             )\n             |> render_submit()\n\n      snap(\"With errors fixed\", render(index_live))\n   end\n```","ref":"readme.html#using-render_component"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}